@@ -12,7 +12,7 @@
 #include "config.h"
 
 #ifndef lint
-static const char sccsid[] = "@(#)api.c	8.23 (Berkeley) 9/15/96";
+static const char sccsid[] = "@(#)api.c	8.26 (Berkeley) 10/14/96";
 #endif /* not lint */
 
 #include <sys/types.h>
@@ -410,31 +410,40 @@ api_unmap(sp, name)
 /*
  * api_opts_get --
  *	Return a option value as a string, in allocated memory.
+ *	If the option is of type boolean, boolvalue is (un)set
+ *	according to the value; otherwise boolvalue is -1.
  *
- * PUBLIC: int api_opts_get __P((SCR *, char *, char **));
+ * PUBLIC: int api_opts_get __P((SCR *, char *, char **, int *));
  */
 int
-api_opts_get(sp, name, value)
+api_opts_get(sp, name, value, boolvalue)
 	SCR *sp;
 	char *name, **value;
+	int *boolvalue;
 {
-	int offset;
 	OPTLIST const *op;
+	int offset;
 
-	if ((op = opts_search(name)) == NULL)
+	if ((op = opts_search(name)) == NULL) {
+		opts_nomatch(sp, name);
 		return (1);
+	}
 
 	offset = op - optlist;
+	if (boolvalue != NULL)
+		*boolvalue = -1;
 	switch (op->type) {
 	case OPT_0BOOL:
 	case OPT_1BOOL:
 		MALLOC_RET(sp, *value, char *, strlen(op->name) + 2 + 1);
 		(void)sprintf(*value,
 		    "%s%s", O_ISSET(sp, offset) ? "" : "no", op->name);
+		if (boolvalue != NULL)
+			*boolvalue = O_ISSET(sp, offset);
 		break;
 	case OPT_NUM:
 		MALLOC_RET(sp, *value, char *, 20);
-		(void)sprintf(*value, "%ld", (u_long)O_VAL(sp, offset));
+		(void)sprintf(*value, "%lu", (u_long)O_VAL(sp, offset));
 		break;
 	case OPT_STR:
 		if (O_STR(sp, offset) == NULL) {
@@ -454,19 +463,51 @@ api_opts_get(sp, name, value)
  * api_opts_set --
  *	Set options.
  *
- * PUBLIC: int api_opts_set __P((SCR *, char *));
+ * PUBLIC: int api_opts_set __P((SCR *, char *, char *, u_long, int));
  */
-int 
-api_opts_set(sp, name)
+int
+api_opts_set(sp, name, str_value, num_value, bool_value)
 	SCR *sp;
-	char *name;
+	char *name, *str_value;
+	u_long num_value;
+	int bool_value;
 {
-	ARGS *ap[2], a;
-	EXCMD cmd;
+	ARGS *ap[2], a, b;
+	OPTLIST const *op;
+	int rval;
+	size_t blen;
+	char *bp;
 
-	ex_cinit(&cmd, C_SET, 0, OOBLNO, OOBLNO, 0, ap);
-	ex_cadd(&cmd, &a, name, strlen(name));
-	return (cmd.cmd->fn(sp, &cmd));
+	if ((op = opts_search(name)) == NULL) {
+		opts_nomatch(sp, name);
+		return (1);
+	}
+
+	switch (op->type) {
+	case OPT_0BOOL:
+	case OPT_1BOOL:
+		GET_SPACE_RET(sp, bp, blen, 64);
+		a.len = snprintf(bp, 64, "%s%s", bool_value ? "" : "no", name);
+		break;
+	case OPT_NUM:
+		GET_SPACE_RET(sp, bp, blen, 64);
+		a.len = snprintf(bp, 64, "%s=%lu", name, num_value);
+		break;
+	case OPT_STR:
+		GET_SPACE_RET(sp, bp, blen, 1024);
+		a.len = snprintf(bp, 1024, "%s=%s", name, str_value);
+		break;
+	}
+	a.bp = bp;
+	b.len = 0;
+	b.bp = NULL;
+	ap[0] = &a;
+	ap[1] = &b;
+	rval = opts_set(sp, ap, NULL);
+
+	FREE_SPACE(sp, bp, blen);
+
+	return (rval);
 }
 
 /*
